@@ -198,7 +198,7 @@ ols_bat_release (MSOleBAT *bat)
  * Returns: a pointer to the element after the last position filled.
  **/
 static guint32 *
-ole_info_read_metabat (GsfInfileMSOle *ole, guint32 *bats, guint32 max,
+ole_info_read_metabat (GsfInfileMSOle *ole, guint32 *bats, guint32 max_bat,
 		       guint32 const *metabat, guint32 const *metabat_end)
 {
 	guint8 const *bat, *end;
@@ -211,7 +211,7 @@ ole_info_read_metabat (GsfInfileMSOle *ole, guint32 *bats, guint32 max,
 			end = bat + ole->info->bb.size;
 			for ( ; bat < end ; bat += BAT_INDEX_SIZE, bats++) {
 				*bats = GSF_LE_GET_GUINT32 (bat);
-				g_return_val_if_fail (*bats < max ||
+				g_return_val_if_fail (*bats < max_bat ||
 						      *bats >= BAT_MAGIC_METABAT, NULL);
 			}
 		} else {
@@ -324,6 +324,11 @@ ole_dirent_new (GsfInfileMSOle *ole, guint32 entry, MSOleDirent *parent)
 		g_warning ("Unknown stream type 0x%x", type);
 		return NULL;
 	}
+	if (!parent && type != DIRENT_TYPE_ROOTDIR) {
+		/* See bug 346118.  */
+		g_warning ("Root directory is not marked as such.");
+		type = DIRENT_TYPE_ROOTDIR;
+	}
 
 	/* It looks like directory (and root directory) sizes are sometimes bogus */
 	size = GSF_LE_GET_GUINT32 (data + DIRENT_FILE_SIZE);
@@ -543,8 +548,10 @@ ole_init_info (GsfInfileMSOle *ole, GError **err)
 	info->max_block	     = (gsf_input_size (ole->input) - OLE_HEADER_SIZE) / info->bb.size;
 	info->sb_file	     = NULL;
 
-	if (info->num_sbat == 0 && info->sbat_start != BAT_MAGIC_END_OF_CHAIN) {
-		g_warning ("There is are not supposed to be any blocks in the small block allocation table, yet there is a link to some.  Ignoring it.");
+	if (info->num_sbat == 0 &&
+	    info->sbat_start != BAT_MAGIC_END_OF_CHAIN &&
+	    info->sbat_start != BAT_MAGIC_UNUSED) {
+		g_warning ("There are not supposed to be any blocks in the small block allocation table, yet there is a link to some.  Ignoring it.");
 	}
 
 	/* very rough heuristic, just in case */
@@ -588,6 +595,13 @@ ole_init_info (GsfInfileMSOle *ole, GError **err)
 			last = num_bat;
 		} else if (num_metabat > 0) {
 			metabat_block = metabat[last];
+			if (num_bat < last) {
+				/* ::num_bat and ::num_metabat are
+				 * inconsistent.  There are too many metabats
+				 * for the bat count in the header. */
+				ptr = NULL;
+				break;
+			}
 			num_bat -= last;
 		}
 
