@@ -925,7 +925,7 @@ msole_prop_cmp (gconstpointer a, gconstpointer b)
 GError *
 gsf_msole_metadata_read	(GsfInput *in, GsfDocMetaData *accum)
 {
-	guint8 const *data = gsf_input_read (in, 28, NULL);
+	guint8 const *data;
 	guint16 version;
 	guint32 os, num_sections;
 	unsigned i, j;
@@ -933,6 +933,12 @@ gsf_msole_metadata_read	(GsfInput *in, GsfDocMetaData *accum)
 	GsfMSOleMetaDataProp	*props;
 	GsfDocProp		*prop;
 	
+	/* http://bugzilla.gnome.org/show_bug.cgi?id=352055 
+	 * psiwin generates files with empty property sections */
+	if (gsf_input_size (in) <= 0)
+		return NULL;
+
+	data = gsf_input_read (in, 28, NULL);
 	if (NULL == data)
 		return g_error_new (gsf_input_error_id (), 0,
 			"Unable to read MS property stream header");
@@ -1023,6 +1029,10 @@ gsf_msole_metadata_read	(GsfInput *in, GsfDocMetaData *accum)
 		if (sections[i].num_props <= 0)
 			continue;
 
+		if (sections[i].num_props > gsf_input_remaining(in) / 8)
+			return g_error_new (gsf_input_error_id (), 0,
+				"Invalid MS property stream header or file truncated");
+
 		/*
 		 * Get and save all the Property ID/Offset pairs.
 		 * Format (bytes) :
@@ -1227,7 +1237,7 @@ msole_metadata_write_prop (WritePropState *state,
 		GSF_LE_SET_FLOAT (buf, g_value_get_float (value));
 		return gsf_output_write (state->out, 4, buf);
 	case VT_R8:
-		GSF_LE_SET_FLOAT (buf, g_value_get_double (value));
+		GSF_LE_SET_DOUBLE (buf, g_value_get_double (value));
 		return gsf_output_write (state->out, 8, buf);
 
 	case VT_LPSTR : {
